@@ -53,36 +53,13 @@ from spatialmath.base import vectors as vec
 from spatialmath.base import transformsNd as trn
 from spatialmath.base import quaternions as quat
 from spatialmath.base import animate
-
-try:  # pragma: no cover
-    # print('Using SymPy')
-    import sympy as sym
-
-    def _issymbol(x):
-        return isinstance(x, sym.Symbol)
-except ImportError:
-    def _issymbol(x):  # pylint: disable=unused-argument
-        return False
+from spatialmath.base import symbolic as sym
 
 _eps = np.finfo(np.float64).eps
 
 # ---------------------------------------------------------------------------------------#
 
 
-def _cos(theta):
-    if _issymbol(theta):
-        return sym.cos(theta)
-    else:
-        return math.cos(theta)
-
-
-def _sin(theta):
-    if _issymbol(theta):
-        return sym.sin(theta)
-    else:
-        return math.sin(theta)
-
-
 def rotx(theta, unit="rad"):
     """
     Create SO(3) rotation about X-axis
@@ -102,8 +79,8 @@ def rotx(theta, unit="rad"):
     """
 
     theta = argcheck.getunit(theta, unit)
-    ct = _cos(theta)
-    st = _sin(theta)
+    ct = sym.cos(theta)
+    st = sym.sin(theta)
     R = np.array([
         [1, 0, 0],
         [0, ct, -st],
@@ -131,8 +108,8 @@ def roty(theta, unit="rad"):
     """
 
     theta = argcheck.getunit(theta, unit)
-    ct = _cos(theta)
-    st = _sin(theta)
+    ct = sym.cos(theta)
+    st = sym.sin(theta)
     R = np.array([
         [ct, 0, st],
         [0, 1, 0],
@@ -159,8 +136,8 @@ def rotz(theta, unit="rad"):
     :seealso: :func:`~yrotz`
     """
     theta = argcheck.getunit(theta, unit)
-    ct = _cos(theta)
-    st = _sin(theta)
+    ct = sym.cos(theta)
+    st = sym.sin(theta)
     R = np.array([
         [ct, -st, 0],
         [st, ct, 0],
@@ -188,10 +165,9 @@ def trotx(theta, unit="rad", t=None):
 
     :seealso: :func:`~rotx`
     """
-    T = np.pad(rotx(theta, unit), (0, 1), mode='constant')
+    T = trn.r2t(rotx(theta, unit))
     if t is not None:
         T[:3, 3] = argcheck.getvector(t, 3, 'array')
-    T[3, 3] = 1.0
     return T
 
 
@@ -216,10 +192,9 @@ def troty(theta, unit="rad", t=None):
 
     :seealso: :func:`~roty`
     """
-    T = np.pad(roty(theta, unit), (0, 1), mode='constant')
+    T = trn.r2t(roty(theta, unit))
     if t is not None:
         T[:3, 3] = argcheck.getvector(t, 3, 'array')
-    T[3, 3] = 1.0
     return T
 
 
@@ -244,10 +219,9 @@ def trotz(theta, unit="rad", t=None):
 
     :seealso: :func:`~rotz`
     """
-    T = np.pad(rotz(theta, unit), (0, 1), mode='constant')
+    T = trn.r2t(rotz(theta, unit))
     if t is not None:
         T[:3, 3] = argcheck.getvector(t, 3, 'array')
-    T[3, 3] = 1.0
     return T
 
 # ---------------------------------------------------------------------------------------#
@@ -296,7 +270,7 @@ def transl(x, y=None, z=None):
         ValueError('bad argument')
 
 
-def ishom(T, check=False, tol=10):
+def ishom(T, check=False, tol=100):
     """
     Test if matrix belongs to SE(3)
 
@@ -316,7 +290,7 @@ def ishom(T, check=False, tol=10):
     return isinstance(T, np.ndarray) and T.shape == (4, 4) and (not check or (trn.isR(T[:3, :3], tol=tol) and np.all(T[3, :] == np.array([0, 0, 0, 1]))))
 
 
-def isrot(R, check=False, tol=10):
+def isrot(R, check=False, tol=100):
     """
     Test if matrix belongs to SO(3)
 
@@ -1231,8 +1205,14 @@ def trinv(T):
 
     """
     assert ishom(T), 'expecting SE(3) matrix'
-    (R, t) = trn.tr2rt(T)
-    return trn.rt2tr(R.T, -R.T@t)
+    # inline this code for speed, don't use tr2rt and rt2tr
+    R = T[:3, :3]
+    t = T[:3, 3]
+    Ti = np.zeros((4,4))
+    Ti[:3, :3] = R.T
+    Ti[:3, 3] = -R.T @ t
+    Ti[3,3] = 1
+    return Ti
 
 
 def tr2delta(T0, T1=None):
@@ -1312,7 +1292,7 @@ def tr2jac(T, samebody=False):
         return np.block([[R.T, Z], [Z, R.T]])
 
 
-def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
+def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', degsym=True, unit='deg'):
     """
     Compact display of SO(3) or SE(3) matrices
 
@@ -1391,11 +1371,15 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', uni
         else:
             seq = None
         angles = tr2rpy(T, order=seq, unit=unit)
-        s += ' {} = {} {}'.format(orient, _vec2s(fmt, angles), unit)
+        if degsym and unit == "deg":
+            fmt += "\u00b0"
+        s += ' {} = {}'.format(orient, _vec2s(fmt, angles))
 
     elif a[0].startswith('eul'):
         angles = tr2eul(T, unit)
-        s += ' eul = {} {}'.format(_vec2s(fmt, angles), unit)
+        if degsym and unit == "deg":
+            fmt += "\u00b0"
+        s += ' eul = {}'.format(_vec2s(fmt, angles))
 
     elif a[0] == 'angvec':
         # as a vector and angle
@@ -1403,7 +1387,10 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', uni
         if theta == 0:
             s += ' R = nil'
         else:
-            s += ' angvec = ({} {} | {})'.format(fmt.format(theta), unit, _vec2s(fmt, v))
+            theta = fmt.format(theta)
+            if degsym and unit == "deg":
+                theta += "\u00b0"
+            s += ' angvec = ({} | {})'.format(theta, _vec2s(fmt, v))
     else:
         raise ValueError('bad orientation format')
 
