@@ -61,10 +61,10 @@ class SO2(SMPose):
         :rtype: SO2 instance
 
         - ``SO2()`` is an SO2 instance representing a null rotation -- the identity matrix.
-        - ``SO2(theta)`` is an SO2 instance representing a rotation by ``theta`` radians.  If ``theta`` is array_like
-          `[theta1, theta2, ... thetaN]` then an SO2 instance containing a sequence of N rotations.
-        - ``SO2(theta, unit='deg')`` is an SO2 instance representing a rotation by ``theta`` degrees.  If ``theta`` is array_like
-          `[theta1, theta2, ... thetaN]` then an SO2 instance containing a sequence of N rotations.
+        - ``SO2(θ)`` is an SO2 instance representing a rotation by ``θ`` radians.  If ``θ`` is array_like
+          `[θ1, θ2, ... θN]` then an SO2 instance containing a sequence of N rotations.
+        - ``SO2(θ, unit='deg')`` is an SO2 instance representing a rotation by ``θ`` degrees.  If ``θ`` is array_like
+          `[θ1, θ2, ... θN]` then an SO2 instance containing a sequence of N rotations.
         - ``SO2(R)`` is an SO2 instance with rotation described by the SO(2) matrix R which is a 2x2 numpy array.  If ``check``
           is ``True`` check the matrix belongs to SO(2).
         - ``SO2([R1, R2, ... RN])`` is an SO2 instance containing a sequence of N rotations, each described by an SO(2) matrix
@@ -72,21 +72,21 @@ class SO2(SMPose):
         - ``SO2([X1, X2, ... XN])`` is an SO2 instance containing a sequence of N rotations, where each Xi is an SO2 instance.
 
         """
-        super().__init__()  # activate the UserList semantics
+        if  super().arghandler(arg, check=check):
+            return
+
+        elif argcheck.isscalar(arg):
+            self.data = [tr.rot2(arg, unit=unit)]
 
-        if arg is None:
-            # empty constructor
-            if isinstance(self, SO2):
-                self.data = [np.eye(2)]
         elif argcheck.isvector(arg):
-            # SO2(value)
-            # SO2(list of values)
-            self.data = [tr.rot2(x, unit) for x in argcheck.getvector(arg)]
+            self.data = [tr.rot2(x, unit=unit) for x in argcheck.getvector(arg)]
 
-        elif isinstance(arg, np.ndarray) and arg.shape == (2, 2):
-            self.data = [arg]
         else:
-            super().arghandler(arg, check=check)
+            raise ValueError('bad argument to constructor')
+
+    @staticmethod
+    def _identity():
+        return np.eye(2)
 
     @property
     def shape(self):
@@ -146,7 +146,7 @@ class SO2(SMPose):
             return cls(tr.trexp2(S, check=check), check=False)
 
     @staticmethod
-    def isvalid(x):
+    def isvalid(x, check=True):
         """
         Test if matrix is valid SO(2)
 
@@ -158,7 +158,7 @@ class SO2(SMPose):
 
         :seealso: :func:`~spatialmath.base.transform3d.isrot`
         """
-        return tr.isrot2(x, check=True)
+        return not check or tr.isrot2(x, check=True)
 
     def inv(self):
         """
@@ -253,22 +253,22 @@ class SE2(SO2):
 
         - ``SE2()`` is an SE2 instance representing a null motion -- the
           identity matrix
-        - ``SE2(theta)`` is an SE2 instance representing a pure rotation of
-          ``theta`` radians
-        - ``SE2(theta, unit='deg')`` as above but ``theta`` in degrees
+        - ``SE2(θ)`` is an SE2 instance representing a pure rotation of
+          ``θ`` radians
+        - ``SE2(θ, unit='deg')`` as above but ``θ`` in degrees
         - ``SE2(x, y)`` is an SE2 instance representing a pure translation of
           (``x``, ``y``)
         - ``SE2(t)`` is an SE2 instance representing a pure translation of
           (``x``, ``y``) where``t``=[x,y] is a 2-element array_like
-        - ``SE2(x, y, theta)`` is an SE2 instance representing a translation of
-          (``x``, ``y``) and a rotation of ``theta`` radians
-        - ``SE2(x, y, theta, unit='deg')`` as above but ``theta`` in degrees
-        - ``SE2(t)`` where ``t``=[x,y] is a 3-element array_like, is an SE2
+        - ``SE2(x, y, θ)`` is an SE2 instance representing a translation of
+          (``x``, ``y``) and a rotation of ``θ`` radians
+        - ``SE2(x, y, θ, unit='deg')`` as above but ``θ`` in degrees
+        - ``SE2(t)`` where ``t``=[x,y] is a 2-element array_like, is an SE2
           instance representing a pure translation of (``x``, ``y``)
-        - ``SE2(t)`` where ``t``=[x,y] is a 3-element array_like, is an SE2
+        - ``SE2(q)`` where ``q``=[x,y,θ] is a 3-element array_like, is an SE2
           instance representing a translation of (``x``, ``y``) and a rotation
-          of ``theta`` radians
-        - ``SE2(t, unit='deg')`` as above but ``theta`` in degrees
+          of ``θ`` radians
+        - ``SE2(t, unit='deg')`` as above but ``θ`` in degrees
         - ``SE2(T)`` is an SE2 instance with rigid-body motion described by the
           SE(2) matrix T which is a 3x3 numpy array.  If ``check`` is ``True``
           check the matrix belongs to SE(2).
@@ -280,38 +280,41 @@ class SE2(SO2):
           N rigid-body motions, where each Xi is an SE2 instance.
 
         """
-        super().__init__()  # activate the UserList semantics
+        if y is None and theta is None:
+            # just one argument passed
 
-        if x is None and y is None and theta is None:
-            # SE2()
-            # empty constructor
-            self.data = [np.eye(3)]
+            if super().arghandler(x, check=check):
+                return
+
+            elif argcheck.isscalar(x):
+                self.data = [tr.trot2(x, unit=unit)]
+            elif len(x) == 2:
+                # SE2([x,y])
+                self.data = [tr.transl2(x)]
+            elif len(x) == 3:
+                # SE2([x,y,theta])
+                self.data = [tr.trot2(x[2], t=x[:2], unit=unit)]
+
+            else:
+                raise ValueError('bad argument to constructor')
 
         elif x is not None:
+            
             if y is not None and theta is None:
                 # SE2(x, y)
                 self.data = [tr.transl2(x, y)]
+        
             elif y is not None and theta is not None:
-                # SE2(x, y, theta)
-                self.data = [tr.trot2(theta, t=[x, y], unit=unit)]
-            elif y is None and theta is None and argcheck.isnumberlist(x):
-                # SE2(arg)
-                arg = argcheck.getvector(x)
-                if len(arg) == 1:
-                    self.data = [tr.trot2(arg[0], unit=unit)]
-                elif len(arg) == 2:
-                    # SE2([x,y])
-                    self.data = [tr.transl2(arg)]
-                elif len(arg) == 3:
-                    # SE2([x,y,theta])
-                    self.data = [tr.trot2(arg[2], t=arg[:2], unit=unit)]
-                else:
-                    super().arghandler(x, check=check)
-            else:
-                self.arghandler(x, check=check)
+                    # SE2(x, y, theta)
+                    self.data = [tr.trot2(theta, t=[x, y], unit=unit)]
+
         else:
             raise ValueError('bad arguments to constructor')
 
+    @staticmethod
+    def _identity():
+        return np.eye(3)
+
     @property
     def shape(self):
         """
@@ -388,7 +391,7 @@ class SE2(SO2):
             return cls(tr.trexp2(S), check=False)
 
     @staticmethod
-    def isvalid(x):
+    def isvalid(x, check=True):
         """
         Test if matrix is valid SE(2)
 
@@ -400,7 +403,7 @@ class SE2(SO2):
 
         :seealso: :func:`~spatialmath.base.transform2d.ishom`
         """
-        return tr.ishom2(x, check=True)
+        return not check or tr.ishom2(x, check=True)
 
     @property
     def t(self):
@@ -481,6 +484,10 @@ class SE2(SO2):
             return y
         return p3.SE3([lift3(x) for x in self])
 
+    def Twist2(self):
+        from spatialmath.twist import Twist2
+
+        return Twist2(self.log(twist=True))
 
 if __name__ == '__main__':  # pragma: no cover
 
