@@ -23,16 +23,14 @@ To use::
 import numpy as np
 
 from spatialmath.base import argcheck
-from spatialmath import base as tr
-# from spatialmath import Twist
+import spatialmath.base as tr
 from spatialmath.super_pose import SMPose
-import spatialmath as sm
 
 
 # ============================== SO3 =====================================#
 
 
-class SO3(SMPose):
+class SO3(SMPose):  
     """
     SO(3) subclass
 
@@ -58,16 +56,13 @@ class SO3(SMPose):
 
         :seealso: `SMPose.pose_arghandler`
         """
-        super().__init__()  # activate the UserList semantics
+        if not super().arghandler(arg, check=check):
+            raise ValueError('bad argument to constructor')
 
-        if arg is None:
-            # empty constructor
-            if isinstance(self, SO3):
-                self.data = [np.eye(3)]  # identity rotation
-        else:
-            super().arghandler(arg, check=check)
-
-# ------------------------------------------------------------------------ #
+    @staticmethod
+    def _identity():
+        return np.eye(3)
+    # ------------------------------------------------------------------------ #
     @property
     def shape(self):
         """
@@ -135,7 +130,7 @@ class SO3(SMPose):
         """
         return self.A[:3, 2]
 
-# ------------------------------------------------------------------------ #
+    # ------------------------------------------------------------------------ #
 
     def inv(self):
         """
@@ -149,9 +144,9 @@ class SO3(SMPose):
         Returns the inverse, which for elements of SO(3) is the transpose.
         """
         if len(self) == 1:
-            return SO3(self.A.T)
+            return SO3(self.A.T, check=False)
         else:
-            return SO3([x.T for x in self.A])
+            return SO3([x.T for x in self.A], check=False)
 
     def eul(self, unit='deg'):
         r"""
@@ -264,10 +259,10 @@ class SO3(SMPose):
             [self.R, tr.skew(self.t) @ self.R],
             [np.zeros((3, 3)), self.R]
             ])
-# ------------------------------------------------------------------------ #
+    # ------------------------------------------------------------------------ #
 
     @staticmethod
-    def isvalid(x):
+    def isvalid(x, check=True):
         """
         Test if matrix is valid SO(3)
 
@@ -281,22 +276,22 @@ class SO3(SMPose):
         """
         return tr.isrot(x, check=True)
 
-# ---------------- variant constructors ---------------------------------- #
+    # ---------------- variant constructors ---------------------------------- #
 
     @classmethod
     def Rx(cls, theta, unit='rad'):
         """
         Construct a new SO(3) from X-axis rotation
 
-        :param theta: rotation angle about the X-axis
-        :type theta: float or array_like
+        :param θ: rotation angle about the X-axis
+        :type θ: float or array_like
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: SO(3) rotation
         :rtype: SO3 instance
 
-        - ``SE3.Rx(theta)`` is an SO(3) rotation of ``theta`` radians about the x-axis
-        - ``SE3.Rx(theta, "deg")`` as above but ``theta`` is in degrees
+        - ``SE3.Rx(θ)`` is an SO(3) rotation of ``θ`` radians about the x-axis
+        - ``SE3.Rx(θ, "deg")`` as above but ``θ`` is in degrees
 
         If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
@@ -318,17 +313,17 @@ class SO3(SMPose):
         """
         Construct a new SO(3) from Y-axis rotation
 
-        :param theta: rotation angle about Y-axis
-        :type theta: float or array_like
+        :param θ: rotation angle about Y-axis
+        :type θ: float or array_like
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: SO(3) rotation
         :rtype: SO3 instance
 
-        - ``SO3.Ry(theta)`` is an SO(3) rotation of ``theta`` radians about the y-axis
-        - ``SO3.Ry(theta, "deg")`` as above but ``theta`` is in degrees
+        - ``SO3.Ry(θ)`` is an SO(3) rotation of ``θ`` radians about the y-axis
+        - ``SO3.Ry(θ, "deg")`` as above but ``θ`` is in degrees
 
-        If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
+        If ``θ`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
 
         Example::
@@ -349,17 +344,17 @@ class SO3(SMPose):
         """
         Construct a new SO(3) from Z-axis rotation
 
-        :param theta: rotation angle about Z-axis
-        :type theta: float or array_like
+        :param θ: rotation angle about Z-axis
+        :type θ: float or array_like
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: SO(3) rotation
         :rtype: SO3 instance
 
-        - ``SO3.Rz(theta)`` is an SO(3) rotation of ``theta`` radians about the z-axis
-        - ``SO3.Rz(theta, "deg")`` as above but ``theta`` is in degrees
+        - ``SO3.Rz(θ)`` is an SO(3) rotation of ``θ`` radians about the z-axis
+        - ``SO3.Rz(θ, "deg")`` as above but ``θ`` is in degrees
 
-        If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
+        If ``θ`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
 
         Example::
@@ -543,7 +538,6 @@ class SO3(SMPose):
         else:
             return cls(tr.trexp(S, check=check), check=False)
 
-
 # ============================== SE3 =====================================#
 
 
@@ -581,28 +575,30 @@ class SE3(SO3):
           check the matrix belongs to SE(3).
         - ``SE3([X1, X2, ... XN])`` where each Xi is an SE3 instance, is an SE3 instance containing N rotations.
         """
-        super().__init__()  # activate the UserList semantics
+        if y is None and z is None:
+            # just one argument passed
 
-        if x is None:
-            # SE3()
-            # empty constructor
-            self.data = [np.eye(4)]
-        elif y is not None and z is not None:
-            # SE3(x, y, z)
-            self.data = [tr.transl(x, y, z)]
-        elif y is None and z is None:
-            if argcheck.isvector(x, 3):
+            if super().arghandler(x, check=check):
+                return
+            elif argcheck.isvector(x, 3):
                 # SE3( [x, y, z] )
                 self.data = [tr.transl(x)]
             elif isinstance(x, np.ndarray) and x.shape[1] == 3:
                 # SE3( Nx3 )
                 self.data = [tr.transl(T) for T in x]
-            else:
-                super().arghandler(x, check=check)
-        else:
-            raise ValueError('bad argument to constructor')
 
-# ------------------------------------------------------------------------ #
+            else:
+                raise ValueError('bad argument to constructor')
+
+        elif y is not None and z is not None:
+            # SE3(x, y, z)
+            self.data = [tr.transl(x, y, z)]
+
+    @staticmethod
+    def _identity():
+        return np.eye(4)
+        
+    # ------------------------------------------------------------------------ #
     @property
     def shape(self):
         """
@@ -633,7 +629,7 @@ class SE3(SO3):
         else:
             return np.array([x[:3, 3] for x in self.A])
 
-# ------------------------------------------------------------------------ #
+    # ------------------------------------------------------------------------ #
 
     def inv(self):
         r"""
@@ -649,7 +645,7 @@ class SE3(SO3):
         :seealso: :func:`~spatialmath.base.transform3d.trinv`
         """
         if len(self) == 1:
-            return SE3(tr.trinv(self.A))
+            return SE3(tr.trinv(self.A), check=False)
         else:
             return SE3([tr.trinv(x) for x in self.A], check=False)
 
@@ -682,43 +678,46 @@ class SE3(SO3):
         return tr.tr2delta(self.A, X2.A)
 
     def Twist3(self):
-        return sm.Twist3(self.log(twist=True))
-# ------------------------------------------------------------------------ #
+
+        from spatialmath.twist import Twist3
+
+        return Twist3(self.log(twist=True))
+    # ------------------------------------------------------------------------ #
 
     @staticmethod
-    def isvalid(x):
+    def isvalid(x, check=True):
         """
         Test if matrix is valid SE(3)
 
         :param x: matrix to test
         :type x: numpy.ndarray
-        :return: true of the matrix is 4x4 and a valid element of SE(3), ie. it is an
-            homogeneous transformation matrix.
+        :return: true of the matrix is 4x4 and a valid element of SE(3), ie. it
+        is an homogeneous transformation matrix.
         :rtype: bool
 
         :seealso: :func:`~spatialmath.base.transform3d.ishom`
         """
-        return tr.ishom(x, check=True)
+        return tr.ishom(x, check=check)
 
-# ---------------- variant constructors ---------------------------------- #
+    # ---------------- variant constructors ---------------------------------- #
 
     @classmethod
     def Rx(cls, theta, unit='rad'):
         """
         Create SE(3) pure rotation about the X-axis
 
-        :param theta: rotation angle about X-axis
-        :type theta: float
+        :param θ: rotation angle about X-axis
+        :type θ: float
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
-        - ``SE3.Rx(THETA)`` is an SO(3) rotation of THETA radians about the x-axis
-        - ``SE3.Rx(THETA, "deg")`` as above but THETA is in degrees
+        - ``SE3.Rx(θ)`` is an SO(3) rotation of θ radians about the x-axis
+        - ``SE3.Rx(θ, "deg")`` as above but θ is in degrees
 
-        If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
-        elements.
+        If ``θ`` is an array then the result is a sequence of rotations defined
+        by consecutive elements.
         """
         return cls([tr.trotx(x, unit) for x in argcheck.getvector(theta)], check=False)
 
@@ -727,17 +726,18 @@ class SE3(SO3):
         """
         Create SE(3) pure rotation about the Y-axis
 
-        :param theta: rotation angle about X-axis
-        :type theta: float
+        :param θ: rotation angle about X-axis
+        :type θ: float
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
-        - ``SE3.Ry(THETA)`` is an SO(3) rotation of THETA radians about the y-axis
-        - ``SE3.Ry(THETA, "deg")`` as above but THETA is in degrees
+        - ``SE3.Ry(θ)`` is an SO(3) rotation of θ radians about the y-axis
+        - ``SE3.Ry(θ, "deg")`` as above but θ is in degrees
 
-        If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
+        If ``θ`` is an array then the result is a sequence of rotations defined
+        by consecutive
         elements.
         """
         return cls([tr.troty(x, unit) for x in argcheck.getvector(theta)], check=False)
@@ -747,18 +747,18 @@ class SE3(SO3):
         """
         Create SE(3) pure rotation about the Z-axis
 
-        :param theta: rotation angle about Z-axis
-        :type theta: float
+        :param θ: rotation angle about Z-axis
+        :type θ: float
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
-        - ``SE3.Rz(THETA)`` is an SO(3) rotation of THETA radians about the z-axis
-        - ``SE3.Rz(THETA, "deg")`` as above but THETA is in degrees
+        - ``SE3.Rz(θ)`` is an SO(3) rotation of θ radians about the z-axis
+        - ``SE3.Rz(θ, "deg")`` as above but θ is in degrees
 
-        If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
-        elements.
+        If ``θ`` is an array then the result is a sequence of rotations defined
+        by consecutive elements.
         """
         return cls([tr.trotz(x, unit) for x in argcheck.getvector(theta)], check=False)
 
@@ -804,11 +804,13 @@ class SE3(SO3):
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
-        ``SE3.Eul(ANGLES)`` is an SO(3) rotation defined by a 3-vector of Euler angles :math:`(\phi, \theta, \psi)` which
-        correspond to consecutive rotations about the Z, Y, Z axes respectively.
+        ``SE3.Eul(ANGLES)`` is an SO(3) rotation defined by a 3-vector of Euler
+        angles :math:`(\phi, \theta, \psi)` which correspond to consecutive
+        rotations about the Z, Y, Z axes respectively.
 
-        If ``angles`` is an Nx3 matrix then the result is a sequence of rotations each defined by Euler angles
-        corresponding to the rows of angles.
+        If ``angles`` is an Nx3 matrix then the result is a sequence of
+        rotations each defined by Euler angles corresponding to the rows of
+        angles.
 
         :seealso: :func:`~spatialmath.pose3d.SE3.eul`, :func:`~spatialmath.pose3d.SE3.Eul`, :func:`spatialmath.base.transforms3d.eul2r`
         """
