@@ -8,6 +8,7 @@ from collections import UserList
 from abc import ABC, abstractproperty, abstractstaticmethod
 import numpy as np
 import spatialmath.base.argcheck as argcheck
+import copy
 
 _numtypes = (int, np.int64, float, np.float64)
 
@@ -68,14 +69,18 @@ class SMUserList(UserList, ABC):
 
     @staticmethod
     @abstractstaticmethod
-    def isvalid(x):
+    def isvalid(x, check=True):
+        pass
+
+    @abstractstaticmethod
+    def _identity():
         pass
 
     def _import(self, x, check=True):
-        if self.isvalid(x):
+        if not check or self.isvalid(x, check=check):
             return x
         else:
-            raise TypeError('bad type passed')
+            return None
 
     @classmethod
     def Empty(cls):
@@ -134,15 +139,19 @@ class SMUserList(UserList, ABC):
             Twist3(SE3())
         """
 
-        if isinstance(arg, np.ndarray):
-            # it's a numpy array
-            self.data = [self._import(arg)]
+        if arg is None:
+            # empty constructor
+            self.data = [self._identity()]
 
-        elif type(arg) == type(self):
-            # it's an object of same type, do copy
-            self.data = arg.data.copy()
-            
-        elif isinstance(arg, list):
+        elif isinstance(arg, np.ndarray):
+            # it's a numpy array
+            x = self._import(arg, check=check)
+            if x is not None:
+                self.data = [x]
+            else:
+                return False
+
+        elif isinstance(arg, (list, tuple)):
             # it's a list of things
             if isinstance(arg[0], np.ndarray):
                 # possibly a list of numpy arrays
@@ -152,8 +161,16 @@ class SMUserList(UserList, ABC):
                 # possibly a list of objects of same type
                 assert all(map(lambda x: type(x) == type(self), arg)), 'elements of list are incorrect type'
                 self.data = [x.A for x in arg]
+
+            elif argcheck.isnumberlist(arg) and len(self.shape) == 1 and len(arg) == self.shape[0]:
+                self.data = [np.array(arg)]
+
             else:
-                raise ValueError('list of unknown values')
+                return False
+
+        elif isinstance(arg, self.__class__):
+            # instance of same type, clone it
+            self.data = copy.copy(arg.data)
 
         elif arg.__class__ in convertfrom:
             # see if we can convert passed argument to this type
@@ -164,8 +181,12 @@ class SMUserList(UserList, ABC):
             except AttributeError:
                 raise ValueError('argument has no conversion method to this type') from None
             self.data = [converter(arg).A]
+
         else:
-            raise ValueError('unknown argument')
+            # don't know this argument, let object __init__ deal with it
+            return False
+
+        return True
 
     @property
     def _A(self):
@@ -528,54 +549,3 @@ class SMUserList(UserList, ABC):
         else:
             return [op(x) for x in self.data]
 
-
-
-#    def binop(left, right, op): 
-
-
-#         if isinstance(right, left.__class__):
-#             # class by class
-#             if len(left) == 1:
-#                 if len(right) == 1:
-#                     #print('== 1x1')
-#                     return op(left.A, right.A)
-#                 else:
-#                     #print('== 1xN')
-#                     return [op(left.A, x) for x in right.A]
-#             else:
-#                 if len(right) == 1:
-#                     #print('== Nx1')
-#                     return [op(x, right.A) for x in left.A]
-#                 elif len(left) == len(right):
-#                     #print('== NxN')
-#                     return [op(x, y) for (x, y) in zip(left.A, right.A)]
-#                 else:
-#                     raise ValueError('length of lists to == must be same length')
-#         elif isinstance(right, (float, int, np.float64, np.int64)) or (isinstance(right, np.ndarray):
-#             # class by matrix
-#             if len(left) == 1:
-#                 return op(left.A, right)
-#             else:
-#                 return [op(x, right) for x in left.A]
-
-
-    # def _op2(self, other, op, list1=True):
-
-    #     if len(self) == 1:
-    #         if len(other) == 1:
-    #             if list1:
-    #                 return [op(self._A, other._A)]
-    #             else:
-    #                 return op(self._A, other._A)
-    #         else:
-    #             #print('== 1xN')
-    #             return [op(self._A, x._A) for x in other]
-    #     else:
-    #         if len(other) == 1:
-    #             #print('== Nx1')
-    #             return [op(x._A, other._A) for x in self]
-    #         elif len(self) == len(other):
-    #             #print('== NxN')
-    #             return [op(x._A, y._A) for (x, y) in zip(self, other)]
-    #         else:
-    #             raise ValueError('length of lists to == must be same length')
\ No newline at end of file
