@@ -17,12 +17,12 @@ References:
 """
 
 from abc import ABC, abstractmethod
-from collections import UserList
 import spatialmath.base.argcheck as arg
 import spatialmath.base as tr
 import numpy as np
+from spatialmath.smuserlist import SMUserList
 
-class SpatialVector(UserList, ABC):
+class SpatialVector(SMUserList):
     """
     Spatial 6-vector abstract superclass
 
@@ -50,7 +50,6 @@ class SpatialVector(UserList, ABC):
     :seealso: :func:`SpatialM6`, :func:`SpatialF6`, :func:`SpatialVelocity`, :func:`SpatialAcceleration`, :func:`SpatialForce`, :func:`SpatialMomentum`.
     """
 
-    @abstractmethod
     def __init__(self, value):
         """
         Create a new spatial vector (abstract superclass)
@@ -80,188 +79,15 @@ class SpatialVector(UserList, ABC):
         else:
             raise ValueError('bad arguments to constructor')
 
-    @classmethod
-    def Empty(cls):
-        """
-        Construct a new spatial vector with zero vectors (superclass method)
+    @staticmethod
+    def _identity():
+        return np.zeros((6,))
+    
+    def isvalid(self, x, check):
+        return True
 
-        :param cls: The spatial vector subclass
-        :type cls: SpatialVelocity, SpatialAcceleration, SpatialForce
-        :return: a spatial vector array with no values
-        :rtype: SpatialVelocity, SpatialAcceleration, SpatialForce or SpatialMomentum instance
-
-        This constructs an empty pose container which can be appended to.  For example::
-
-            >>> x = SpatialVelocity.Empty()
-            >>> len(x)
-            0
-            >>> x.append(SpatialVelocity([1,2,3,4,5,6)
-            >>> len(x)
-            1
-
-        """
-        X = cls()
-        X.data = []
-        return X
-
-        # ------------------------------------------------------------------------ #
-
-    def __getitem__(self, i):
-        """
-        Access value of a spatial object (superclass method)
-
-        :param i: index of element to return
-        :type i: int
-        :return: the specific element of the pose
-        :rtype: SO2, SE2, SO3, SE3 instance
-        :raises IndexError: if the element is out of bounds
-
-        Note that only a single index is supported, slices are not.
-
-        Example::
-
-            >>> x = SE3.Rx([0, math.pi/2, math.pi])
-            >>> len(x)
-            3
-            >>> x[1]
-               1           0           0           0
-               0           0          -1           0
-               0           1           0           0
-               0           0           0           1
-        """
-        print('getitem', i)
-        if isinstance(i, slice):
-            return self.__class__([self.data[k] for k in range(i.start or 0, i.stop or len(self), i.step or 1)])
-        else:
-            return self.__class__(self.data[i])
-
-    def __setitem__(self, i, value):
-        """
-        Assign a value to a pose object (superclass method)
-
-        :param i: index of element to assign to
-        :type i: int
-        :param value: the value to insert
-        :type value: SO2, SE2, SO3, SE3 instance
-        :raises ValueError: incorrect type of assigned value
-
-        Assign the argument to an element of the object's internal list of values.
-        This supports the assignement operator, for example::
-
-            >>> x = SE3([SE3() for i in range(10)]) # sequence of ten identity values
-            >>> len(x)
-            10
-            >>> x[3] = SE3.Rx(0.2)   # assign to position 3 in the list
-        """
-        if not type(self) == type(value):
-            raise ValueError("cant append different type of pose object")
-        if len(value) > 1:
-            raise ValueError("cant insert a pose sequence - must have len() == 1")
-        self.data[i] = value.A
-
-    def append(self, x):
-        """
-        Append a value to a pose object (superclass method)
-
-        :param x: the value to append
-        :type x: SO2, SE2, SO3, SE3 instance
-        :raises ValueError: incorrect type of appended object
-
-        Appends the argument to the object's internal list of values.
-
-        Examples::
-
-            >>> x = SE3()
-            >>> len(x)
-            1
-            >>> x.append(SE3.Rx(0.1))
-            >>> len(x)
-            2
-        """
-        print('in append method')
-        if not type(self) == type(x):
-            raise ValueError("cant append different type of spatial vector")
-        if len(x) > 1:
-            raise ValueError("cant append a spatial vector sequence - use extend")
-        super().append(x.V)
-
-    def extend(self, x):
-        """
-        Extend sequence of values of a pose object (superclass method)
-
-        :param x: the value to extend
-        :type x: SO2, SE2, SO3, SE3 instance
-        :raises ValueError: incorrect type of appended object
-
-        Appends the argument to the object's internal list of values.
-
-        Examples::
-
-            >>> x = SE3()
-            >>> len(x)
-            1
-            >>> x.append(SE3.Rx(0.1))
-            >>> len(x)
-            2
-        """
-        # print('in extend method')
-        if not type(self) == type(x):
-            raise ValueError("cant append different type of pose object")
-        if len(x) == 0:
-            raise ValueError("cant extend a singleton pose  - use append")
-        super().extend(x.A)
-
-    def insert(self, i, value):
-        """
-        Insert a value to a pose object (superclass method)
-
-        :param i: element to insert value before
-        :type i: int
-        :param value: the value to insert
-        :type value: SO2, SE2, SO3, SE3 instance
-        :raises ValueError: incorrect type of inserted value
-
-        Inserts the argument into the object's internal list of values.
-
-        Examples::
-
-            >>> x = SE3()
-            >>> x.insert(0, SE3.Rx(0.1)) # insert at position 0 in the list
-            >>> len(x)
-            2
-        """
-        if not type(self) == type(value):
-            raise ValueError("cant append different type of pose object")
-        if len(value) > 1:
-            raise ValueError("cant insert a pose sequence - must have len() == 1")
-        super().insert(i, value.V)
-
-    def pop(self):
-        """
-        Pop value of a pose object (superclass method)
-
-        :return: the specific element of the pose
-        :rtype: SO2, SE2, SO3, SE3 instance
-        :raises IndexError: if there are no values to pop
-
-        Removes the first pose value from the sequence in the pose object.
-
-        Example::
-
-            >>> x = SE3.Rx([0, math.pi/2, math.pi])
-            >>> len(x)
-            3
-            >>> y = x.pop()
-            >>> y
-            SE3(array([[ 1.0000000e+00,  0.0000000e+00,  0.0000000e+00,  0.0000000e+00],
-                       [ 0.0000000e+00, -1.0000000e+00, -1.2246468e-16,  0.0000000e+00],
-                       [ 0.0000000e+00,  1.2246468e-16, -1.0000000e+00,  0.0000000e+00],
-                       [ 0.0000000e+00,  0.0000000e+00,  0.0000000e+00,  1.0000000e+00]]))
-            >>> len(x)
-            2
-        """
-
-        return self.__class__(super().pop())
+    def shape(self):
+        return (6,)
 
     # ------------------------------------------------------------------------ #
     @property
@@ -327,7 +153,7 @@ class SpatialVector(UserList, ABC):
         return  self.__class__([-x for x in self.data])
 
 
-    def __add__(left, right):
+    def __add__(left, right):  # pylint: disable=no-self-argument
         """
         Addition for spatial vectors
 
@@ -344,7 +170,7 @@ class SpatialVector(UserList, ABC):
 
         return left.__class__([x + y for x, y in zip(left.data, right.data)])
 
-    def __sub__(left, right):
+    def __sub__(left, right):  # pylint: disable=no-self-argument
         """
         Subtraction Addition for spatial vectors
 
@@ -446,14 +272,14 @@ class SpatialM6(SpatialVector):
         else:
             raise TypeError('type mismatch')
 
-    def __mul(left, right):
+    def __mul(left, right):  # pylint: disable=no-self-argument
         return left.cross(right)
 
-    def __rmul(right, left):
+    def __rmul(right, left):  # pylint: disable=no-self-argument
         if isinstance(left, SpatialInertia):
             # result is SpatialMomentum
             pass  # TODO
-        elif isinstance(left, Twist):
+        elif isinstance(left, Twist3):
             # result is transformed SpatialVelocity or SpatialAcceleration
             # Twist * SpatialVelocity -> SpatialVelocity
             # Twist * SpatialAcceleration -> SpatialAcceleration
@@ -585,7 +411,7 @@ class SpatialForce(SpatialF6):
         super().__init__(value)
 # n = SpatialForce(val);
 
-    def __rmul(right, left):
+    def __rmul(right, left):  # pylint: disable=no-self-argument
         # Twist * SpatialForce -> SpatialForce
         return SpatialForce(left.Ad.T @ right.V)
 
@@ -609,7 +435,7 @@ class SpatialMomentum(SpatialF6):
     def __init__(self, value=None):
         super().__init__(value)
 
-class SpatialInertia(UserList):
+class SpatialInertia(SMUserList):
     """
     Spatial inertia class
 
@@ -683,7 +509,7 @@ class SpatialInertia(UserList):
         return str(self.I)
 
 
-    def __add__(left, right):
+    def __add__(left, right):  # pylint: disable=no-self-argument
         """
         Spatial inertia addition
         :param left:
@@ -697,7 +523,7 @@ class SpatialInertia(UserList):
         assert type(left) == type(right), 'spatial inertia can only be added to spatial inertia'
         return SpatialInertia(a.I + b.I)
 
-    def __mul__(left, right):
+    def __mul__(self, right):  # pylint: disable=no-self-argument
         """
         Spatial inertia product
 
@@ -709,17 +535,18 @@ class SpatialInertia(UserList):
           the SpatialAcceleration ``A``.
         - ``SI * V`` is the SpatialMomemtum of a body with SpatialInertia ``SI`` and SpatialVelocity ``V``.
         """
+        left = self
 
         if isinstance(right, SpatialAcceleration):
-            v = SpatialForce(a.I * b.vw);  # F = ma
-        elif instance(right, SpatialVelocity):
+            v = SpatialForce(left.I @ right.V)  # F = ma
+        elif isinstance(right, SpatialVelocity):
             # crf(v(i).vw)*model.I(i).I*v(i).vw;
             # v = Wrench( a.cross() * I.I * a.vw );
-            v = SpatialMomentum(a.I * b.vw)   # M = mv
+            v = SpatialMomentum(left.I * right.V)   # M = mv
         else:
             raise TypeError('bad postmultiply operands for Inertia *')
 
-    def __rmul__(right, left):
+    def __rmul__(self, left):  # pylint: disable=no-self-argument
         """
         Spatial inertia product
 
@@ -731,7 +558,7 @@ class SpatialInertia(UserList):
           the SpatialAcceleration ``A``.
         - ``V * SI `` is the SpatialMomemtum of a body with SpatialInertia ``SI`` and SpatialVelocity ``V``.
         """
-        return right.__mul__(left)
+        return self.__mul__(left)
 
 if __name__ == "__main__":
 
@@ -951,4 +778,4 @@ if __name__ == "__main__":
             pass
 
 
-    unittest.main(buffer=True)
\ No newline at end of file
+    unittest.main(buffer=True)
