@@ -8,17 +8,10 @@ import copy
 from spatialmath.base import argcheck
 from spatialmath import base as tr
 from spatialmath.smuserlist import SMUserList
-
+from spatialmath.base import symbolic as sym
 
 _eps = np.finfo(np.float64).eps
 
-try:
-    import sympy
-    _sympy = True
-except ImportError:
-    _sympy = False
-
-
 # colored printing of matrices to the terminal
 #   colored package has much finer control than colorama, but the latter is available by default with anaconda
 try:
@@ -435,8 +428,8 @@ class SMPose(SMUserList):
 
         .. todo:: No need to simplify the constants in bottom row
         """
-        vf = np.vectorize(sympy.simplify)
-        return self.__class__([vf(x) for x in self.data], chec=False)
+        vf = np.vectorize(sym.simplify)
+        return self.__class__([vf(x) for x in self.data], check=False)
 
     # ----------------------- i/o stuff
 
@@ -446,13 +439,15 @@ class SMPose(SMUserList):
 
         :param label: text label to put at start of line
         :type label: str
-        :param file: file to write formatted string to. [default, stdout]
-        :type file: str
         :param fmt: conversion format for each number as used by ``format()``
         :type fmt: str
+        :param label: text label to put at start of line
+        :type label: str
+        :param orient: 3-angle convention to use
+        :type orient: str
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
-        :return: optional formatted string
+        :return: formatted string
         :rtype: str
 
         For SO(3) or SE(3) also:
@@ -526,7 +521,15 @@ class SMPose(SMUserList):
             In [1]: x
 
         """
-        print(self.__str__())
+        # see https://ipython.org/ipython-doc/stable/api/generated/IPython.lib.pretty.html
+        s = str(self).split('\n')
+        p.begin_group(4, self.__class__.__name__ + ':' +  s[0])
+        p.break_()
+        for i, s in enumerate(s[1:]):
+            p.text(s)
+            if i < len(s) - 2:
+                p.break_()
+        p.end_group(4, '')
 
     def __str__(self):
         """
@@ -557,7 +560,7 @@ class SMPose(SMUserList):
         """
         return self._string(color=True)
 
-    def _string(self, color=False, tol=10):
+    def _string(self, color=False, tol=500):
         """
         Pretty print the matrix value
 
@@ -586,10 +589,21 @@ class SMPose(SMUserList):
 
         """
         #print('in __str__', _color)
-
-        def FG(c): return fg(c) if _color else ''
-        def BG(c): return bg(c) if _color else ''
-        def ATTR(c): return attr(c) if _color else ''
+        
+        if _color:
+            # bgcol = bg('grey_93')
+            bgcol = ''
+            trcol = fg('blue')
+            rotcol = fg('red')
+            constcol = fg('grey_50')
+            reset = attr(0)
+            indexcol = bg('yellow_2')
+        else:
+            bgcol = ''
+            trcol = ''
+            rotcol = ''
+            constcol = ''
+            reset = ''
 
         def mformat(self, X):
             # X is an ndarray value to be display
@@ -600,7 +614,7 @@ class SMPose(SMUserList):
                 rowstr = '  '
                 # format the columns
                 for colnum, element in enumerate(row):
-                    if _sympy and isinstance(element, sympy.Expr):
+                    if sym.issymbol(element):
                         s = '{:<12s}'.format(str(element))
                     else:
                         if tol > 0 and abs(element) < tol * _eps:
@@ -610,15 +624,15 @@ class SMPose(SMUserList):
                     if rownum < n:
                         if colnum < n:
                             # rotation part
-                            s = FG('red') + BG('grey_93') + s + ATTR(0)
+                            s = rotcol + bgcol + s + reset
                         else:
                             # translation part
-                            s = FG('blue') + BG('grey_93') + s + ATTR(0)
+                            s = trcol + bgcol + s + reset
                     else:
                         # bottom row
-                        s = FG('grey_50') + BG('grey_93') + s + ATTR(0)
+                        s = constcol + bgcol + s + reset
                     rowstr += s
-                out += rowstr + BG('grey_93') + '  ' + ATTR(0) + '\n'
+                out += rowstr + bgcol + '  ' + reset + '\n'
             return out
 
         output_str = ''
@@ -632,7 +646,8 @@ class SMPose(SMUserList):
             # sequence case
             for count, X in enumerate(self.data):
                 # add separator lines and the index
-                output_str += fg('green') + '[{:d}] =\n'.format(count) + attr(0) + mformat(self, X)
+                output_str += indexcol + '[{:d}] ='.format(count) + reset \
+                    + '\n' + mformat(self, X)
 
         return output_str
 
@@ -695,7 +710,7 @@ class SMPose(SMUserList):
     #----------------------- arithmetic
 
 
-    def __mul__(left, right):
+    def __mul__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``*`` operator (superclass method)
 
@@ -804,12 +819,12 @@ class SMPose(SMUserList):
                 return np.c_[[tr.h2e(x.A @ tr.e2h(y)) for x, y in zip(right, left.T)]].T
             else:
                 raise ValueError('bad operands')
-        elif isinstance(right, (int, np.int64, float, np.float64)):
+        elif argcheck.isscalar(right):
             return left._op2(right, lambda x, y: x * y)
         else:
             return NotImplemented
 
-    def __rmul__(right, left):
+    def __rmul__(right, left):  # pylint: disable=no-self-argument
         """
         Overloaded ``*`` operator (superclass method)
 
@@ -826,15 +841,15 @@ class SMPose(SMUserList):
 
         #. For other left-operands return ``NotImplemented``.  Other classes
           such as ``Plucker`` and ``Twist`` implement left-multiplication by
-          an ``SE33`` using their own ``__rmul__`` methods.
+          an ``SE3`` using their own ``__rmul__`` methods.
 
         """
-        if isinstance(left, (int, np.int64, float, np.float64)):
+        if argcheck.isscalar(left):
             return right.__mul__(left)
         else:
             return NotImplemented
 
-    def __imul__(left, right):
+    def __imul__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``*=`` operator (superclass method)
 
@@ -851,6 +866,20 @@ class SMPose(SMUserList):
         """
         return left.__mul__(right)
 
+    def prod(self):
+        r"""
+        Product of elements
+
+        :return: Product of elements
+
+        For a pose instance with N values return the matrix product of those
+        elements :math:`\prod_i^N T_i`.
+        """
+        Tprod = self.__class__._identity()  # identity value
+        for T in self.data:
+            Tprod = Tprod @ T
+        return self.__class__(Tprod)
+
     def __pow__(self, n):
         """
         Overloaded ``**`` operator (superclass method)
@@ -870,7 +899,7 @@ class SMPose(SMUserList):
     # def __ipow__(self, n):
     #     return self.__pow__(n)
 
-    def __truediv__(left, right):
+    def __truediv__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``/`` operator (superclass method)
 
@@ -917,28 +946,12 @@ class SMPose(SMUserList):
         """
         if isinstance(left, right.__class__):
             return left.__class__(left._op2(right.inv(), lambda x, y: x @ y), check=False)
-        elif isinstance(right, (int, np.int64, float, np.float64)):
+        elif argcheck.isscalar(right):
             return left._op2(right, lambda x, y: x / y)
         else:
             raise ValueError('bad operands')
 
-    # def __itruediv__(left, right):
-    #     """
-    #     Overloaded ``/=`` operator (superclass method)
-
-    #     :arg left: left dividend
-    #     :arg right: right divisor
-    #     :return: quotient
-    #     :raises: ValueError
-
-    #     - ``X /= Y`` compounds the poses ``X`` and ``Y.inv()`` and places the result in ``X``
-    #     - ``X /= s`` performs elementwise division of the elements of ``X`` by ``s``
-
-    #     :seealso: ``__truediv__``
-    #     """
-    #     return left.__truediv__(right)
-
-    def __add__(left, right):
+    def __add__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``+`` operator (superclass method)
 
@@ -990,7 +1003,7 @@ class SMPose(SMUserList):
         # results is not in the group, return an array, not a class
         return left._op2(right, lambda x, y: x + y)
 
-    def __radd__(left, right):
+    def __radd__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``+`` operator (superclass method)
 
@@ -1009,7 +1022,7 @@ class SMPose(SMUserList):
     # def __iadd__(left, right):
     #     return left.__add__(right)
 
-    def __sub__(left, right):
+    def __sub__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``-`` operator (superclass method)
 
@@ -1061,7 +1074,7 @@ class SMPose(SMUserList):
         # TODO allow class +/- a conformant array
         return left._op2(right, lambda x, y: x - y)
 
-    def __rsub__(left, right):
+    def __rsub__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``-`` operator (superclass method)
 
@@ -1080,7 +1093,7 @@ class SMPose(SMUserList):
     # def __isub__(left, right):
     #     return left.__sub__(right)
 
-    def __eq__(left, right):
+    def __eq__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``==`` operator (superclass method)
 
@@ -1112,7 +1125,7 @@ class SMPose(SMUserList):
         assert type(left) == type(right), 'operands to == are of different types'
         return left._op2(right, lambda x, y: np.allclose(x, y))
 
-    def __ne__(left, right):
+    def __ne__(left, right):  # pylint: disable=no-self-argument
         """
         Overloaded ``!=`` operator
 
@@ -1141,9 +1154,9 @@ class SMPose(SMUserList):
         =========   ==========   ====  ================================
 
         """
-        return [not x for x in self == right]
+        return [not x for x in left == right]
 
-    def _op2(left, right, op):
+    def _op2(left, right, op):  # pylint: disable=no-self-argument
         """
         Perform binary operation
 
@@ -1190,9 +1203,15 @@ class SMPose(SMUserList):
                     return [op(x, y) for (x, y) in zip(left.A, right.A)]
                 else:
                     raise ValueError('length of lists to == must be same length')
-        elif isinstance(right, (float, int, np.float64, np.int64)) or (isinstance(right, np.ndarray) and right.shape == left.shape):
+        elif argcheck.isscalar(right) or (isinstance(right, np.ndarray) and right.shape == left.shape):
             # class by matrix
             if len(left) == 1:
                 return op(left.A, right)
             else:
                 return [op(x, right) for x in left.A]
+
+if __name__ == "__main__":
+    from spatialmath import SE3
+    x = SE3.Rand(N=6)
+
+    print(x)
\ No newline at end of file
